@@ -37,5 +37,9 @@ class karyotype():
         ax.tick_params(labelsize=15)
         ax.spines['top'].set_visible(False)
         ax.spines['right'].set_visible(False)
+        ax.spines['left'].set_visible(False)
+        ax.spines['bottom'].set_visible(False)
+        ax.set_xticks([])
+        ax.set_yticks([])
         plt.savefig(self.savefig, dpi=500)
         plt.show()
